==> R14.0.6-core.tar: tdevelop-trinity-14.0.6/languages/java/javasupportfactory.cpp <==
/***************************************************************************
 *   Copyright (C) 2000-2001 by Bernd Gehrmann                             *
 *   bernd@kdevelop.org                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kinstance.h>
#include <kstandarddirs.h>
#include <kdevplugininfo.h>
#include "javasupportfactory.h"

static const KDevPluginInfo data("kdevjavasupport");
K_EXPORT_COMPONENT_FACTORY( libkdevjavasupport, JavaSupportFactory )

JavaSupportFactory::JavaSupportFactory()
    : KDevGenericFactory<JavaSupportPart>( data )
{
}

TDEInstance *JavaSupportFactory::createInstance()
{
    TDEInstance *instance = KDevGenericFactory<JavaSupportPart>::createInstance();
    TDEStandardDirs *dirs = instance->dirs();
    dirs->addResourceType( "newclasstemplates", TDEStandardDirs::kde_default("data") + "kdevjavasupport/newclass/" );
    dirs->addResourceType( "pcs", TDEStandardDirs::kde_default( "data" ) + "kdevjavasupport/pcs/" );

    return instance;
}

const KDevPluginInfo *JavaSupportFactory::info()
{
    return &data;
}

==> R14.1.4-core.tar: tdevelop-trinity-14.1.4/languages/java/javasupportfactory.cpp <==
/***************************************************************************
 *   Copyright (C) 2000-2001 by Bernd Gehrmann                             *
 *   bernd@kdevelop.org                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kinstance.h>
#include <kstandarddirs.h>
#include <kdevplugininfo.h>
#include "javasupportfactory.h"

static const KDevPluginInfo pluginData("kdevjavasupport");
K_EXPORT_COMPONENT_FACTORY( libkdevjavasupport, JavaSupportFactory )

JavaSupportFactory::JavaSupportFactory()
    : KDevGenericFactory<JavaSupportPart>( pluginData )
{
}

TDEInstance *JavaSupportFactory::createInstance()
{
    TDEInstance *instance = KDevGenericFactory<JavaSupportPart>::createInstance();
    TDEStandardDirs *dirs = instance->dirs();
    dirs->addResourceType( "newclasstemplates", TDEStandardDirs::kde_default("data") + "kdevjavasupport/newclass/" );
    dirs->addResourceType( "pcs", TDEStandardDirs::kde_default( "data" ) + "kdevjavasupport/pcs/" );

    return instance;
}

const KDevPluginInfo *JavaSupportFactory::info()
{
    return &pluginData;
}
